@@ -91,7 +91,7 @@ Gamma <- function(shape, rate = 1) {
 
 #' @export
 mean.Gamma <- function(x, ...) {
-  ellipsis::check_dots_used()
+  rlang::check_dots_used()
   rval <- x$shape / x$rate
   setNames(rval, names(x))
 }
@@ -134,7 +134,7 @@ random.Gamma <- function(x, n = 1L, drop = TRUE, ...) {
   if (n == 0L) {
     return(numeric(0L))
   }
-  FUN <- function(at, d) rgamma(n = at, shape = x$shape, rate = x$rate)
+  FUN <- function(at, d) rgamma(n = at, shape = d$shape, rate = d$rate)
   apply_dpqr(d = x, FUN = FUN, at = n, type = "random", drop = drop)
 }
 
@@ -231,7 +231,7 @@ cdf.Gamma <- function(d, x, drop = TRUE, elementwise = NULL, ...) {
 #' @export
 #'
 quantile.Gamma <- function(x, probs, drop = TRUE, elementwise = NULL, ...) {
-  FUN <- function(at, d) qgamma(at, shape = x$shape, rate = x$rate, ...)
+  FUN <- function(at, d) qgamma(at, shape = d$shape, rate = d$rate, ...)
   apply_dpqr(d = x, FUN = FUN, at = probs, type = "quantile", drop = drop, elementwise = elementwise)
 }
 
@@ -271,7 +271,7 @@ suff_stat.Gamma <- function(d, x, ...) {
 #'
 #' @export
 support.Gamma <- function(d, drop = TRUE, ...) {
-  ellipsis::check_dots_used()
+  rlang::check_dots_used()
   min <- rep(0, length(d))
   max <- rep(Inf, length(d))
   make_support(min, max, d, drop = drop)
@@ -279,12 +279,12 @@ support.Gamma <- function(d, drop = TRUE, ...) {
 
 #' @exportS3Method
 is_discrete.Gamma <- function(d, ...) {
-  ellipsis::check_dots_used()
+  rlang::check_dots_used()
   setNames(rep.int(FALSE, length(d)), names(d))
 }
 
 #' @exportS3Method
 is_continuous.Gamma <- function(d, ...) {
-  ellipsis::check_dots_used()
+  rlang::check_dots_used()
   setNames(rep.int(TRUE, length(d)), names(d))
 }
