@@ -664,7 +664,7 @@ StatAuc <- ggplot2::ggproto("StatAuc", ggplot2::Stat,
         round(cdf(d, to) - cdf(d, from), digits = digits)
       )
     } else {
-      data$label <- NA
+      data$label <- ""
     }
 
     return(data)
@@ -732,7 +732,7 @@ geom_auc <- function(mapping = NULL,
 GeomAuc <- ggplot2::ggproto("GeomAuc", ggplot2::GeomArea,
   required_aes = c("x", "y", "label"),
   default_aes = ggplot2::aes(
-    colour = NA, fill = "grey40", size = 0.5, linetype = 1,
+    colour = NA, fill = "grey40", linewidth = 0.5, linetype = 1,
     alpha = NA
   ),
   draw_panel = function(data,
@@ -754,7 +754,7 @@ GeomAuc <- ggplot2::ggproto("GeomAuc", ggplot2::GeomArea,
         y = Inf,
         label = data$label[1],
         colour = annotate,
-        size = 3.88 * data$size[1] * 2,
+        size = 3.88 * data$linewidth[1] * 2,
         angle = 0,
         hjust = -0.1,
         vjust = 2,
