@@ -1,7 +1,5 @@
-context("test-Cauchy")
-
 test_that("print.Cauchy works", {
-  expect_output(print(Cauchy(1, 1)), regexp = "Cauchy distribution")
+  expect_output(print(Cauchy(1, 1)), regexp = "Cauchy")
 })
 
 test_that("likelihood.Cauchy and log_likelihood.Cauchy work correctly", {
@@ -23,7 +21,7 @@ test_that("random.Cauchy work correctly", {
   expect_length(random(cau[-1], 1), 0)
   expect_length(random(cau, 0), 0)
   expect_error(random(cau, -2))
- 
+
   # consistent with base R, using the `length` as number of samples to draw
   expect_length(random(cau, c(1, 2, 3)), 3)
   expect_length(random(cau, cbind(1, 2, 3)), 3)
