@@ -1,7 +1,5 @@
-context("test-Frechet")
-
 test_that("print.Frechet works", {
-  expect_output(print(Frechet()), regexp = "Frechet distribution")
+  expect_output(print(Frechet()), regexp = "Frechet")
 })
 
 ## Example distributions
@@ -35,7 +33,7 @@ test_that("random.Frechet works correctly", {
   expect_length(random(g1[-1], 1), 0)
   expect_length(random(g1, 0), 0)
   expect_error(random(g1, -2))
- 
+
   # consistent with base R, using the `length` as number of samples to draw
   expect_length(random(g1, c(1, 2, 3)), 3)
   expect_length(random(g1, cbind(1, 2, 3)), 3)
@@ -110,6 +108,35 @@ test_that("vectorization of a Frechet distribution work correctly", {
       ncol = 3, dimnames = list(NULL, c("q_0.1", "q_0.5", "q_0.9"))
     )
   )
+
+  ## elementwise
+  expect_equal(
+    pdf(d, c(0.25, 0.75), elementwise = TRUE),
+    diag(pdf(d, c(0.25, 0.75), elementwise = FALSE))
+  )
+  expect_equal(
+    cdf(d, c(0.25, 0.75), elementwise = TRUE),
+    diag(cdf(d, c(0.25, 0.75), elementwise = FALSE))
+  )
+  expect_equal(
+    quantile(d, c(0.25, 0.75), elementwise = TRUE),
+    diag(quantile(d, c(0.25, 0.75), elementwise = FALSE))
+  )
+
+  ## support
+  expect_equal(
+    support(d),
+    matrix(
+      c(support(d1)[1], support(d2)[1], support(d1)[2], support(d2)[2]),
+      ncol = 2, dimnames = list(names(d), c("min", "max"))
+    )
+  )
+  expect_true(!any(is_discrete(d)))
+  expect_true(all(is_continuous(d)))
+  expect_true(is.numeric(support(d1)))
+  expect_true(is.numeric(support(d1, drop = FALSE)))
+  expect_null(dim(support(d1)))
+  expect_equal(dim(support(d1, drop = FALSE)), c(1L, 2L))
 })
 
 test_that("named return values for Frechet distribution work correctly", {
@@ -134,4 +161,7 @@ test_that("named return values for Frechet distribution work correctly", {
   expect_equal(names(quantile(d, 0.5)), LETTERS[1:length(d)])
   expect_equal(names(quantile(d, c(0.5, 0.7))), LETTERS[1:length(d)])
   expect_equal(rownames(quantile(d, c(0.5, 0.7, 0.9))), LETTERS[1:length(d)])
+  expect_equal(names(support(d[1])), c("min", "max"))
+  expect_equal(colnames(support(d)), c("min", "max"))
+  expect_equal(rownames(support(d)), LETTERS[1:length(d)])
 })
