@@ -1,7 +1,5 @@
-context("test-ZIPoisson")
-
 test_that("print.ZIPoisson works", {
-  expect_output(print(ZIPoisson(1, 0.2)), regexp = "ZIPoisson distribution")
+  expect_output(print(ZIPoisson(1, 0.2)), regexp = "ZIPoisson")
 })
 
 test_that("random.ZIPoisson work correctly", {
@@ -12,7 +10,7 @@ test_that("random.ZIPoisson work correctly", {
   expect_length(random(p[-1], 1), 0)
   expect_length(random(p, 0), 0)
   expect_error(random(p, -2))
- 
+
   # consistent with base R, using the `length` as number of samples to draw
   expect_length(random(p, c(1, 2, 3)), 3)
   expect_length(random(p, cbind(1, 2, 3)), 3)
