@@ -1,3 +1,5 @@
+is.ggplot <- if (packageVersion("ggplot2") < "3.5.2") ggplot2::is.ggplot else ggplot2::is_ggplot
+
 test_that("Error thrown for incorrect input to plot.distribution", {
   expect_error(plot.distribution(1))
 })
@@ -46,39 +48,39 @@ test_that("ggplot2 implementation works", {
 
   ## plot pdf of continous distribution
   gg1 <- plot_pdf(N1) + geom_auc(to = -0.645)
-  expect_true(ggplot2::is.ggplot(gg1))
+  expect_true(is.ggplot(gg1))
   expect_silent(print(gg1))
   gg2 <- plot_pdf(N1) + geom_auc(from = -0.645, to = 0.1, annotate = TRUE)
-  expect_true(ggplot2::is.ggplot(gg2))
+  expect_true(is.ggplot(gg2))
   expect_silent(print(gg2))
   gg3 <- plot_pdf(N2) + geom_auc(to = 0)
-  expect_true(ggplot2::is.ggplot(gg3))
+  expect_true(is.ggplot(gg3))
   expect_silent(print(gg3))
   gg4 <- plot_pdf(N2) + geom_auc(from = -2, to = 2, annotate = TRUE)
-  expect_true(ggplot2::is.ggplot(gg4))
+  expect_true(is.ggplot(gg4))
   expect_silent(print(gg4))
 
   ## plot pdf of discrete distribution
   gg5 <- plot_pdf(B1)
-  expect_true(ggplot2::is.ggplot(gg5))
+  expect_true(is.ggplot(gg5))
   expect_silent(print(gg5))
   gg6 <- plot_pdf(B2)
-  expect_true(ggplot2::is.ggplot(gg6))
+  expect_true(is.ggplot(gg6))
   expect_silent(print(gg6))
 
   ## plot pdf of discrete distribution
   gg7 <- plot_cdf(N1)
-  expect_true(ggplot2::is.ggplot(gg7))
+  expect_true(is.ggplot(gg7))
   expect_silent(print(gg7))
   gg8 <- plot_cdf(N2)
-  expect_true(ggplot2::is.ggplot(gg8))
+  expect_true(is.ggplot(gg8))
   expect_silent(print(gg8))
 
   ## plot pdf of discrete distribution
   gg9 <- plot_cdf(B1)
-  expect_true(ggplot2::is.ggplot(gg9))
+  expect_true(is.ggplot(gg9))
   expect_silent(print(gg9))
   gg10 <- plot_cdf(B2)
-  expect_true(ggplot2::is.ggplot(gg10))
+  expect_true(is.ggplot(gg10))
   expect_silent(print(gg10))
 })
